@@ -126,8 +126,10 @@ class VCSFileStartHook(hook.Hook):
         interval = self.repo.config.get('check-revision-interval')
         if interval < 0:
             return
+        repo = self.repo
         def refresh_vcsrepos():
-            return _refresh_repos(self.repo)
+            from cubes.vcsfile.hooks import _refresh_repos as refresh
+            return refresh(repo)
         self.repo.looping_task(interval, refresh_vcsrepos)
 
 # internals to be able to create new vcs repo revision using rql queries #######
