@@ -220,7 +220,7 @@ class HGRepository(repo.VCSRepository):
                              repoentity.dc_title(), self.path)
                 # clean all 'revision' attribute to please unicity
                 # constraint when renumbering
-                session.execute('SET R revision 0-REV WHERE R revision REV, R from_repository REPO, '
+                session.execute('SET R revision -1-REV WHERE R revision REV, R from_repository REPO, '
                                 'REPO eid %(reid)s', {'reid': repoentity.eid})
                 revs = session.execute('Any R WHERE R is Revision, R from_repository REPO, '
                                        'REPO eid %(reid)s', {'reid': repoentity.eid})
@@ -254,7 +254,7 @@ class HGRepository(repo.VCSRepository):
             # XXX we need to update obsolescence markers without new revision
             #     involved.
             knownheads = [str(r.changeset) for r in repoentity.heads_rset().entities()]
-            missing = repo.revs("not ::%ls", knownheads)
+            missing = list(repo.revs("not ::%ls", knownheads))
             missing.sort()
             while missing:
                 for rev in missing[:commitevery]:
