@@ -8,6 +8,13 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
     ignored_relations = set(('at_revision', 'parent_revision',
                              'from_repository', 'from_revision', 'content_for',))
 
+    def to_test_etypes(self):
+        return set(('Repository',
+                    'Revision',
+                    'VersionedFile',
+                    'DeletedVersionContent',
+                    'VersionContent'))
+
     def custom_populate(self, how_many, cursor):
         req = self.request()
         req.create_entity('Repository', type=u'mercurial',
