@@ -8,7 +8,6 @@
 __docformat__ = "restructuredtext en"
 
 
-from cubicweb import typed_eid
 from cubicweb.predicates import match_form_params
 from cubicweb.web import Redirect, RequestError
 from cubicweb.web.controller import Controller
@@ -21,11 +20,9 @@ class RefreshLocalRepoCachesController(Controller):
     __select__ = Controller.__select__ & match_form_params('eid')
 
     def publish(self, rset=None):
-        eid = typed_eid(self._cw.form['eid'])
+        eid = int(self._cw.form['eid'])
         vcsrepo = self._cw.entity_from_eid(eid)
         if vcsrepo.e_schema.type != 'Repository':
             raise RequestError('a repository is expected')
-        # async=False so that users see changes immediately, if any
-        self._cw.cnx.call_service('refresh_repository', async=False,
-                                  eids=(vcsrepo.eid,))
+        self._cw.cnx.call_service('refresh_repository', eids=(vcsrepo.eid,))
         raise Redirect(vcsrepo.absolute_url())
