@@ -18,9 +18,9 @@ from cubicweb.predicates import (match_form_params, match_kwargs,
                                  match_edited_type)
 from cubicweb import Forbidden
 from cubicweb.view import EntityView
-from cubicweb.web import (Redirect, RequestError, controller, uicfg, form,
+from cubicweb.web import (Redirect, RequestError, controller, form,
                           formfields as ff, formwidgets as fw)
-from cubicweb.web.views import autoform, forms, editcontroller
+from cubicweb.web.views import autoform, forms, editcontroller, uicfg
 
 from cubes.vcsfile import IMMUTABLE_ATTRIBUTES
 
